<?php

use WSCOMUN\WSComunFClient;

ini_set("soap.wsdl_cache_enabled", 0);

require_once '../../include/WSComunFClient.php';
$keyGDE2 		= WSComunFClient::KEYCLIENTE_GDE2;


/* Array de URIs con los WSDLs descriptivos de cada servicio SAFE disponible */
$v_wsdl = array
(
		$keyGDE2 => 'https://instrumental-pre.gva.es/pai_bus_ins/GDE/GDEService_v2_00?wsdl'	// Instrumentales
		//$keyGDE2 => 		'https://preinterint.gva.es/eSirca_Bus/ins/Proxy/GDE/GdeWSService_v2_00?wsdl'
);

/* Datos del certificado utilizado para las pruebas */
$v_datosCertif = array
(
	'certFile'	=> realpath('../../cert/SELLO-SCOR-PRE.crt'),
	'keyFile'	=> realpath('../../cert/SELLO-SCOR-PRE.key'),
	'passPhrase'=> null
);

$vTrazabilidad = array
(
	'nsCert'=>	'2039d6a41976eedf',
	'idApp'=>	'WSCOMUN'
);


//Parametros de invocacin generales
/*
 * La primera ejecucin $crearCarpeta y $crearDocumento deben ser 'true' para que se cree el marco de trabajo
 * En sucesivas ejecuciones, las variables $crearCarpeta y $crearDocumento deben ser 'false'
 * En caso de bloqueo, cambiar la carpeta de trabajo ($path), y lanzar una primera ejecucin para que cree el marco de trabajo
 */
$codApp = 'RABA';

// Variables de funcionamiento
$path = '/testObtenerExpedienteC';
$debugMode = false;
$borrarCarpeta = false;
$crearCarpeta = false;
$crearDocumento = false;

try
{
	set_time_limit(40);
	$clienteSIRCA = WSComunFClient::makeWSClient(WSComunFClient::KEYCLIENTE_GDE2, $v_wsdl, array_merge($v_datosCertif, $vTrazabilidad));
	$clienteSIRCA->setDebugMode(true);
	$clienteSIRCA->loadTracertPAI($vTrazabilidad);

	// EliminarCarpeta
	if ($borrarCarpeta) {
		$respuestaGDE2 = $clienteSIRCA->eliminarCarpetaGDE2($codApp, $path);
		if ($debugMode) {
			echo "<br>\nCarpeta '" . $path . "' eliminada correctamente: " . ($respuestaGDE2['respuesta']['correcto'] != 'false' ? "True" : "False") . "<br>\n";
		}
	}

	// CrearCarpeta
	if ($crearCarpeta) {
		$metadatosExpedienteEni = array(
				'versionNTI' => 'http://administracionelectronica.gob.es/ENI/XSD/v1.0/documento-e',
				'organo' => 'A10000PRE',
				'identificador' => 'ES_A10000PRE_2013_EXP_000000000000000000000001234567',
				'fechaAperturaExpediente' => new DateTime('2015-05-20T11:29:38.468+02:00'),
				'estado' => 'E01',
				'clasificacion' => 'CLASIFICACION',
				'interesado' => array( 'lmhubeda' ) // 1 or more
		);
		$coleccionMetadatosPersonalizados = array(
				array(
						'idColeccionMetadatosPersonalizados' => 'gde:incorporable',
						'tipoColeccion' => 'ASPECTO',
						'metadatosPersonalizados' => array(
								array(
										'idMetaDatoPers' => 'gde:eni_u_t_fecha_incorporacion_expediente',
										'tipoMetaDatoPers' => 'FECHA',
										'valorMetaDatoPers' => array( new DateTime('2015-05-20T11:29:38.468+02:00') )
								)
						)
				)
		);

		$respuestaGDE2 = $clienteSIRCA->crearCarpetaGDE2($codApp, $path, null, $metadatosExpedienteEni, $coleccionMetadatosPersonalizados);
		if ($debugMode) {
			echo "<br>\nCarpeta '" . $path . "' creada correctamente: " . ($respuestaGDE2['respuesta']['correcto'] != 'false' ? "True" : "False"). "<br>\n";
		}
	}


	if ($crearDocumento) {
		// GenerarIdentificadorENI (2)
		$respuestaGDE2 = $clienteSIRCA->generarIdentificadorENIGDE2($codApp);
		$idENI2 = $respuestaGDE2['respuesta']['identificadorENI'];
		if ($debugMode) {
			echo "<br>\nIdentificador ENI (2): $idENI2<br>\n";
		}


		// InsertarDocumentoENI
		$contenidoPDF = file_get_contents('docENI_NLZ.xml');
		//$contenidoPDFB64 = base64_encode ($contenidoPDF);
		$nombreDoc = 'prueba.eni';
		$vMetaENI = array(
				'versionNTI' => 'http://administracionelectronica.gob.es/ENI/XSD/v1.0/documento-e',
				'identificador' => $idENI2,
				'tipoDocumental' => 'TD99',
				'nombreFormato' => '4',
				'organo' => array( 'A10000PRE' ),		// 1 or more
				'fechaCaptura' => new DateTime(),
				'estadoElaboracion' => 'EE99',
				'origenCiudadanoAdministracion' => true,
				'identificadorDocumentoOrigen' => '9',
				'fechaIncorporacionExpediente' => new DateTime()
		);
		$vMetaPers = array(
				array(
				'idColeccionMetadatosPersonalizados' => 'P:gde:mezquita_datos_contenido',
				'tipoColeccion' => 'ASPECTO',
				'metadatosPersonalizados' => array(
						array(
								'idMetaDatoPers' => 'gde:mez_u_s_sensibilidad_LOPD',
								'tipoMetaDatoPers' => 'CADENA',
								'valorMetaDatoPers' => array( 'A' )
						)
				)
			)
		);
		$vFirmas = array(
				array(
				'tipo' => 'TF01',
				'fechaFirma' => new DateTime('2014-07-23T09:25:17.030+02:00'),
				'CSV' => 'CKDK49390909FJ8984JF9834JF',
				'regCSV' => 'BOE'
			)
		);

		if ($debugMode) {
			print("\n\n<br><br><br>Prueba de GDE: insertarDocumentoENIGDE2($codApp, CONTENIDOPDF, $nombreDoc)<br>\n<br>\n");
		}
		$respuestaGDE = $clienteSIRCA->insertarDocumentoENIGDE2($codApp, $contenidoPDF, $nombreDoc, $path, null, $vMetaENI, $vMetaPers, $vFirmas);
		if ($debugMode) {
			echo ("Referencia Documento: " . $respuestaGDE['referenciaDocumento'] . "<br>\n");
			echo ("Nombre documento: " . $respuestaGDE['nombre'] . "<br>\n");
		}
	}



	// obtenerExpedienteENIdeCarpetaGDE2
	$idCertificadoSafe = '5';
	$idSesionSafe = 'TRA';

	$respuestaGDE2 = $clienteSIRCA->obtenerExpedienteENIdeCarpetaGDE2($codApp, $path, $idCertificadoSafe, $idSesionSafe);
	if ($debugMode) {
		print("<br>\Respuesta de obtenerExpedienteENIGDE2<br>\n");
		var_dump($respuestaGDE2);die;
	} else {
		// Genera el fichero para descarga (con extension temporal)
		$contenido = base64_decode( $respuestaGDE2['respuesta']['expedienteElectronicoENI'] );

		ob_end_clean();
		ob_start();
		header("Content-Type: application/zip");
		header("Content-Disposition: attachment; filename='expENICarp.zip'");
		header('Expires: 0');
		header('Pragma: cache');
		header('Cache-Control: private');
		echo $contenido;
		ob_end_flush();
	}
}
catch (Exception $e)
{
	print("\n<br/>Error: \n<br/>");
	print($e->getMessage());print("\n<br/>");
	print('<pre>');
	$vDebugInfo = is_object($clienteSIRCA)?$clienteSIRCA->getDebugInfo():array('Error en la creacin del objeto WSComunFClient');
	print_r($vDebugInfo);
	print('</pre>');
}

?>